[java-opensaml] branch master updated: Adjust variable names.

Scott Cantor cantor.2 at osu.edu
Mon Jun 15 23:41:21 UTC 2020


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch master
in repository java-opensaml.

View the commit online:
http://git.shibboleth.net/view/?p=java-opensaml.git;a=commit;h=a32524a7d365e05b8a56b103d23e2a2a45627cc2

The following commit(s) were added to refs/heads/master by this push:
       new  a32524a7d Adjust variable names.
a32524a7d is described below

commit a32524a7d365e05b8a56b103d23e2a2a45627cc2
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Mon Jun 15 19:41:17 2020 -0400

    Adjust variable names.
---
 .../provider/FilesystemConfigurationPropertiesSourceTest.java  | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/opensaml-core/src/test/java/org/opensaml/core/config/provider/FilesystemConfigurationPropertiesSourceTest.java b/opensaml-core/src/test/java/org/opensaml/core/config/provider/FilesystemConfigurationPropertiesSourceTest.java
index 2d5acb8c6..d961ca2bc 100644
--- a/opensaml-core/src/test/java/org/opensaml/core/config/provider/FilesystemConfigurationPropertiesSourceTest.java
+++ b/opensaml-core/src/test/java/org/opensaml/core/config/provider/FilesystemConfigurationPropertiesSourceTest.java
@@ -37,8 +37,8 @@ public class FilesystemConfigurationPropertiesSourceTest {
     /** The source test to test. */
     private ConfigurationPropertiesSource source;
     
-    /** Master file with test data. */
-    private File masterFile;
+    /** Main file with test data. */
+    private File mainFile;
     
     /** Actual target file test runs against. */
     private File targetFile;
@@ -49,15 +49,15 @@ public class FilesystemConfigurationPropertiesSourceTest {
      * @throws IOException ...
      */
     public FilesystemConfigurationPropertiesSourceTest() throws IOException {
-        masterFile = new File("src/test/resources/opensaml-config.properties");
+        mainFile = new File("src/test/resources/opensaml-config.properties");
         targetFile = File.createTempFile("opensaml-config.properties", "");
-        System.out.println(masterFile.getAbsolutePath());
+        System.out.println(mainFile.getAbsolutePath());
         System.out.println(targetFile.getAbsolutePath()); 
     }
     
     @BeforeMethod
     protected void setUp() throws Exception {
-        Files.copy(masterFile, targetFile);
+        Files.copy(mainFile, targetFile);
     }
 
     @AfterMethod

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list